==> org-lsst-ccs-ui-2.2.6-sources.jar: org/lsst/ccs/gconsole/plugins/plots/LsstPlotsPlugin.java <==
package org.lsst.ccs.gconsole.plugins.plots;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.Plugin;

/**
 * Graphical console plugin that displays AIDA plots published on the status bus.
 * @author turri
 */
@Plugin(name="LSST Plots Plugin",
        description="Allows displaying AIDA plots published on the status bus.")
public class LsstPlotsPlugin extends ConsolePlugin {

// -- Fields : -----------------------------------------------------------------
    
    static public final String AUTO_START = "autoStart";
    
    private final Action plotsAction;
    private PlotsListener plotListener;

// -- Life cycle : -------------------------------------------------------------
    
    public LsstPlotsPlugin() {
        plotsAction = new AbstractAction("Plots") {
            @Override
            public void actionPerformed(ActionEvent e) {
                LsstPlotsPlugin.this.setEnabled((Boolean) getValue(Action.SELECTED_KEY));
            }
        };
        plotsAction.putValue(Action.SELECTED_KEY, false);
    }
    
    @Override
    synchronized public void initialize(){
        
        getServices().addMenu(plotsAction, "400: CCS Tools :-1:7");
        
        getServices().addProperty(AUTO_START, false);
        getServices().addPreference(new String[] {"LSST","AIDA Plots"}, null, "${"+ AUTO_START +"}Start on console sturtup.");
    }

    @Override
    public void start() {
        boolean enable = (Boolean) getServices().getProperty(AUTO_START);
        if (enable) setEnabled(true);
    }
    
    synchronized public void setEnabled(boolean enable) {
        plotsAction.putValue(Action.SELECTED_KEY, enable);
        if (enable) {
            plotListener = new PlotsListener();
            getConsole().getMessagingAccess().addStatusMessageListener(plotListener);
        } else {
            getConsole().getMessagingAccess().removeStatusMessageListener(plotListener);
            plotListener = null;
        }
    }

}

==> org-lsst-ccs-ui-2.3.7-sources.jar: org/lsst/ccs/gconsole/plugins/plots/LsstPlotsPlugin.java <==
package org.lsst.ccs.gconsole.plugins.plots;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.Action;
import org.lsst.ccs.gconsole.base.ConsolePlugin;
import org.lsst.ccs.gconsole.annotations.Plugin;

/**
 * Graphical console plugin that displays AIDA plots published on the status bus.
 * @author turri
 */
@Plugin(name="LSST Plots Plugin",
        description="Allows displaying AIDA plots published on the status bus.")
public class LsstPlotsPlugin extends ConsolePlugin {

// -- Fields : -----------------------------------------------------------------
    
    static public final String AUTO_START = "autoStart";
    
    private final Action plotsAction;
    private PlotsListener plotListener;

// -- Life cycle : -------------------------------------------------------------
    
    public LsstPlotsPlugin() {
        plotsAction = new AbstractAction("Plots") {
            @Override
            public void actionPerformed(ActionEvent e) {
                LsstPlotsPlugin.this.setEnabled((Boolean) getValue(Action.SELECTED_KEY));
            }
        };
        plotsAction.putValue(Action.SELECTED_KEY, false);
    }
    
    @Override
    synchronized public void initialize(){
        
        getServices().addMenu(plotsAction, "400: CCS Tools :-1:7");
        
        getServices().addProperty(AUTO_START, false);
        getServices().addPreference(new String[] {"LSST","AIDA Plots"}, null, "${"+ AUTO_START +"}Start on console sturtup.");
    }

    @Override
    public void start() {
        boolean enable = (Boolean) getServices().getProperty(AUTO_START);
        if (enable) setEnabled(true);
    }
    
    synchronized public void setEnabled(boolean enable) {
        plotsAction.putValue(Action.SELECTED_KEY, enable);
        if (enable) {
            plotListener = new PlotsListener();
            getConsole().getMessagingAccess().addStatusMessageListener(plotListener);
        } else {
            getConsole().getMessagingAccess().removeStatusMessageListener(plotListener);
            plotListener = null;
        }
    }

}
